@@ -1,5 +1,5 @@
 class MLPNotAvailableError(Exception):
-    """Raised when MLP is not available.""" 
+    """Raised when MLP is not available."""
     pass
 
 class MLPFailedError(Exception):
@@ -19,4 +19,12 @@ class NotSupportedError(Exception):
     pass
 
 class InvalidInputError(Exception):
-    """Raised when invalid input is received."""
\ No newline at end of file
+    """Raised when invalid input is received."""
+
+class PosLabelNotSpecifiedError(Exception):
+    """Raised when positive label is not specified with binary label set."""
+    pass
+
+class InvalidScoringIdentifierError(Exception):
+    """Raises when scoring identifier is not present in metrics_map."""
+    pass
